# "fix" underlinking:
%define _disable_ld_no_undefined 1

%define up_name		freerdp2

%define winpr_major	2
%define uwac_major	0
%define major		2
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define rc_ver		0
%define rc_name		rc4
%if %{rc_ver}
%define release		%mkrel -c %{rc_name} %{rel}
%define tarballver	%{version}-%{rc_name}
%else
%define release		%mkrel %{rel}
%define tarballver	%{version}
%endif

%define rel 3

# Momentarily disable GSS support (mga#32100)
# https://github.com/FreeRDP/FreeRDP/issues/4348
%bcond_with gss

Name:		freerdp
Version:	2.11.7
Release:	%{release}
Summary:	A free remote desktop protocol client
License:	Apache License
Group:		Networking/Remote access
Url:		https://www.freerdp.com/
Source0:	https://pub.freerdp.com/releases/%{name}-%{tarballver}.tar.gz
Patch0:		CVE-2024-32661.patch

BuildRequires:	cmake
BuildRequires:	docbook-style-xsl
BuildRequires:	xmlto
BuildRequires:	cups-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	gsm-devel
BuildRequires:	lame-devel
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xkbfile)
BuildRequires:	pkgconfig(xv)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(gstreamer-1.0)
BuildRequires:	pkgconfig(gstreamer-base-1.0)
BuildRequires:	pkgconfig(gstreamer-app-1.0)
BuildRequires:	pkgconfig(gstreamer-audio-1.0)
BuildRequires:	pkgconfig(gstreamer-fft-1.0)
BuildRequires:	pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:	pkgconfig(gstreamer-video-1.0)
%if %{with gss}
BuildRequires:	pkgconfig(krb5) >= 1.13
%endif
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	pkgconfig(wayland-client)
BuildRequires:	pkgconfig(wayland-scanner)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(xkbcommon)
BuildRequires:	pkgconfig(zlib)

%description
FreeRDP is a fork of the rdesktop project.

#----------------------------------------------------

%package -n	%{libname}
Summary:	Main library for %{name}
Group:		System/Libraries

%description -n	%{libname}
Shared libraries for %{name}.

#----------------------------------------------------

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Development files and headers for %{name}.

#----------------------------------------------------

%prep
%autosetup -p1

%build
# FIXME:
# Workaround GCC 14 build error
%global optflags %{optflags} -Wno-incompatible-pointer-types -Wno-int-conversion

%cmake \
    -Wno-dev \
    -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
    -DWITH_ALSA=ON \
    -DWITH_CUPS=ON \
    -DWITH_CHANNELS=ON -DBUILTIN_CHANNELS=OFF \
    -DWITH_CLIENT=ON \
    -DWITH_DIRECTFB=OFF \
    -DWITH_GSM=ON \
    -DWITH_GSSAPI=%{?with_gss:ON}%{?!with_gss:OFF} \
    -DWITH_GSTREAMER_1_0=ON -DWITH_GSTREAMER_0_10=OFF \
    -DGSTREAMER_1_0_INCLUDE_DIRS=%{_includedir}/gstreamer-1.0 \
    -DWITH_IPP=OFF \
    -DWITH_JPEG=ON \
    -DWITH_LAME=ON \
    -DWITH_MANPAGES=OFF \
    -DWITH_OPENSSL=ON \
    -DWITH_PCSC=ON \
    -DWITH_PULSE=ON \
    -DWITH_SERVER=ON -DWITH_SERVER_INTERFACE=ON \
    -DWITH_SHADOW_X11=ON -DWITH_SHADOW_MAC=ON \
    -DWITH_WAYLAND=ON \
    -DWITH_X11=ON \
    -DWITH_XCURSOR=ON \
    -DWITH_XEXT=ON \
    -DWITH_XKBFILE=ON \
    -DWITH_XI=ON \
    -DWITH_XINERAMA=ON \
    -DWITH_XRENDER=ON \
    -DWITH_XTEST=OFF \
    -DWITH_XV=ON \
    -DWITH_ZLIB=ON \
    -DWITH_FFMPEG=ON \
    -DWITH_SWSCALE=ON \
%ifarch x86_64
    -DWITH_SSE2=ON \
%else
    -DWITH_SSE2=OFF \
%endif
%ifarch armv7hl
    -DARM_FP_ABI=hard \
    -DWITH_NEON=OFF \
%endif
%ifarch armv7hnl
    -DARM_FP_ABI=hard \
    -DWITH_NEON=ON \
%endif
%ifarch armv5tl armv5tel armv6l armv7l
    -DARM_FP_ABI=soft \
    -DWITH_NEON=OFF \
%endif

%cmake_build

%install
%cmake_install

# we don't want these
find %{buildroot} -name '*.la' -delete
find %{buildroot} -name '*.a' -delete

# Delete executables we do not need and conflicts with freerdp3
rm -rfv %{buildroot}%{_bindir}

%files
%doc ChangeLog README.md
%license LICENSE
%{_libdir}/%{name}2/

%files -n %{libname}
%doc ChangeLog README.md
%license LICENSE
%{_libdir}/lib*%{name}*.so.%{major}{,.*}
%{_libdir}/libwinpr*.so.%{winpr_major}{,.*}
%{_libdir}/libuwac*.so.%{uwac_major}{,.*}

%files -n %{develname}
%doc ChangeLog README.md
%{_libdir}/*.so
%{_includedir}/%{up_name}/
%{_includedir}/winpr*/
%{_includedir}/uwac*/
%{_libdir}/pkgconfig/%{name}*.pc
%{_libdir}/pkgconfig/winpr*.pc
%{_libdir}/pkgconfig/uwac*.pc
%{_libdir}/cmake/FreeRDP*/
%{_libdir}/cmake/WinPR*/
%{_libdir}/cmake/uwac*/


%changelog
* Wed Mar 19 2025 ns80 <ns80> 2.11.7-3.mga10
+ Revision: 2166689
- add patch from Debian for CVE-2024-32661 (mga#34086)

* Sun Dec 08 2024 daviddavid <daviddavid> 2.11.7-2.mga10
+ Revision: 2122898
- rebuild for new ffmpeg 7.1

* Mon Apr 22 2024 daviddavid <daviddavid> 2.11.7-1.mga10
+ Revision: 2060494
- new version: 2.11.7

* Thu Apr 18 2024 daviddavid <daviddavid> 2.11.6-1.mga10
+ Revision: 2058787
- new version: 2.11.6

* Fri Feb 09 2024 daviddavid <daviddavid> 2.11.5-2.mga10
+ Revision: 2039891
- drop binaries and manpages that conflict now with freerdp3

* Fri Jan 19 2024 daviddavid <daviddavid> 2.11.5-1.mga10
+ Revision: 2032198
- new version: 2.11.5

* Sat Dec 23 2023 daviddavid <daviddavid> 2.11.4-1.mga10
+ Revision: 2021016
- new version: 2.11.4

* Wed Sep 20 2023 daviddavid <daviddavid> 2.11.2-1.mga10
+ Revision: 1988429
- new version: 2.11.2

* Mon Sep 04 2023 daviddavid <daviddavid> 2.11.1-1.mga10
+ Revision: 1984071
- new version: 2.11.1

* Fri Sep 01 2023 daviddavid <daviddavid> 2.11.0-1.mga10
+ Revision: 1983293
- new version: 2.11.0

* Tue Aug 01 2023 daviddavid <daviddavid> 2.10.0-2.mga9
+ Revision: 1964362
- finally disable gssapi support as it breaks remmina (mga#32100)

* Sat Feb 18 2023 daviddavid <daviddavid> 2.10.0-1.mga9
+ Revision: 1943837
- new version: 2.10.0

* Thu Feb 09 2023 daviddavid <daviddavid> 2.9.0-3.mga9
+ Revision: 1939766
- enable mp3lame support

* Sat Dec 24 2022 daviddavid <daviddavid> 2.9.0-2.mga9
+ Revision: 1926365
- enable gssapi support

* Fri Nov 25 2022 ns80 <ns80> 2.9.0-1.mga9
+ Revision: 1911006
- new version 2.9.0 for CVE-2022-3931[6-9], CVE-2022-39320, CVE-2022-39347 (mga#31173)

* Mon Nov 14 2022 daviddavid <daviddavid> 2.8.1-1.mga9
+ Revision: 1907333
- new version: 2.8.1

* Fri Aug 19 2022 luigiwalser <luigiwalser> 2.8.0-1.mga9
+ Revision: 1878745
- 2.8.0

* Thu Apr 28 2022 tv <tv> 2.7.0-1.mga9
+ Revision: 1854906
- Update to 2.7.0.

* Tue Mar 22 2022 tv <tv> 2.6.1-1.mga9
+ Revision: 1816985
- Update to 2.6.1 for gnome-remote-desktop

* Sat Mar 12 2022 mrambo3501 <mrambo3501> 2.4.1-3.mga9
+ Revision: 1790663
- rebuild for ffmpeg 5.0

* Mon Nov 15 2021 ns80 <ns80> 2.4.1-2.mga9
+ Revision: 1756694
- new version 2.4.1 for CVE-2021-41159 and CVE-2021-41160 (mga#29654)

* Sun Oct 03 2021 tmb <tmb> 2.4.0-2.mga9
+ Revision: 1748848
- rebuild for openssl-3.0.0

* Thu Aug 05 2021 luigiwalser <luigiwalser> 2.4.0-1.mga9
+ Revision: 1739562
- 2.4.0

* Mon Mar 15 2021 daviddavid <daviddavid> 2.3.2-1.mga9
+ Revision: 1703435
- new version: 2.3.2

* Sun Mar 07 2021 daviddavid <daviddavid> 2.3.1-1.mga9
+ Revision: 1700411
- new version: 2.3.1

* Fri Feb 26 2021 daviddavid <daviddavid> 2.3.0-1.mga9
+ Revision: 1691924
- new version: 2.3.0

* Mon Jul 20 2020 daviddavid <daviddavid> 2.2.0-1.mga8
+ Revision: 1607474
- new version: 2.2.0

* Wed Jun 24 2020 daviddavid <daviddavid> 2.1.2-1.mga8
+ Revision: 1599096
- new version: 2.1.2

* Mon May 25 2020 tv <tv> 2.1.1-2.mga8
+ Revision: 1587545
- rebuild for new x265

* Sat May 23 2020 daviddavid <daviddavid> 2.1.1-1.mga8
+ Revision: 1586912
- new version: 2.1.1

* Fri May 08 2020 daviddavid <daviddavid> 2.1.0-1.mga8
+ Revision: 1581725
- new version: 2.1.0

* Fri Apr 10 2020 daviddavid <daviddavid> 2.0.0-3.mga8
+ Revision: 1565978
- really enable image scaling support

* Fri Apr 10 2020 daviddavid <daviddavid> 2.0.0-2.mga8
+ Revision: 1565977
- enable image scaling support (cairo)

* Thu Apr 09 2020 daviddavid <daviddavid> 2.0.0-1.mga8
+ Revision: 1565870
- new version: 2.0.0 (final)
- remove merged upstream patch

* Mon Feb 24 2020 daviddavid <daviddavid> 2.0.0-0.rc4.3.mga8
+ Revision: 1550124
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Dec 04 2019 daviddavid <daviddavid> 2.0.0-0.rc4.2.mga8
+ Revision: 1464214
- add patch to fix CVE-2019-17177 and CVE-2019-17178 (mga#25815)

* Tue Nov 20 2018 daviddavid <daviddavid> 2.0.0-0.rc4.1.mga7
+ Revision: 1332251
- new version: 2.0.0-rc4 (Fifth release candidate for 2.0.0)

* Wed Oct 03 2018 pterjan <pterjan> 2.0.0-0.rc3.2.mga7
+ Revision: 1316240
- Mageia 7 Mass Rebuild

* Fri Aug 03 2018 daviddavid <daviddavid> 2.0.0-0.rc3.1.mga7
+ Revision: 1247003
- new version: 2.0.0_rc3

* Wed Jun 13 2018 tv <tv> 2.0.0-0.rc2.3.mga7
+ Revision: 1236646
- disable ffmpeg support
- enable alsa, gstreamer, openssl & pam support
- enable channels (needed disabling underlinking)

* Thu Apr 26 2018 daviddavid <daviddavid> 2.0.0-0.rc2.2.mga7
+ Revision: 1222556
- rebuild for new ffmpeg 4.0

* Thu Apr 12 2018 daviddavid <daviddavid> 2.0.0-0.rc2.1.mga7
+ Revision: 1217871
- new version: 2.0.0-rc2 (Third release candidate for 2.0.0)

* Sat Dec 16 2017 daviddavid <daviddavid> 2.0.0-0.rc1.1.mga7
+ Revision: 1182768
- new version: 2.0.0-rc1 (Second release candidate for 2.0.0)

* Fri Sep 01 2017 daviddavid <daviddavid> 2.0.0-0.rc0.2.mga7
+ Revision: 1150409
- rebuild for new openssl 1.1.0f

* Fri Jul 28 2017 daviddavid <daviddavid> 2.0.0-0.rc0.1.mga7
+ Revision: 1131996
- new version: 2.0.0-rc0 (First release candidate for 2.0.0)

* Tue May 02 2017 akien <akien> 2.0.0-0.git20161228.3.mga6
+ Revision: 1098287
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 2.0.0-0.git20161228.2.mga6
+ Revision: 1089854
- Rebuild for ffmpeg 3.2.4

* Sun Jan 01 2017 daviddavid <daviddavid> 2.0.0-0.git20161228.1.mga6
+ Revision: 1079495
- new snapshot release: 2.0.0-git20161228 (sixth attempt of freerdp 2)
  * commit: 90877f5acb61bdba5bf5a3cc4e7f42f42b0c51a2

* Wed Nov 02 2016 daviddavid <daviddavid> 2.0.0-0.git20161005.1.mga6
+ Revision: 1064736
- new snapshot release: 2.0.0-git20161005 (fifth attempt of freerdp 2)
  * commit: 1d06087b601a4cc723592e9a6efbf9bee0dc2d12
- enable sse2 only on x86_64 arch

* Fri Aug 12 2016 daviddavid <daviddavid> 2.0.0-0.git20160722.1.mga6
+ Revision: 1046080
- new snapshot release: 2.0.0-git20160722 (fourth attempt of freerdp 2)
  * commit: 5b2455f3147aca395a441fc65b602938600f0788

* Wed May 18 2016 daviddavid <daviddavid> 2.0.0-0.git20160513.1.mga6
+ Revision: 1016624
- new snapshot release: 2.0.0-git20160513 (third attempt of freerdp 2)
  * commit: 4e66df7228b14e432a0793d32ac2524d37cb88ec

* Mon Mar 28 2016 daviddavid <daviddavid> 2.0.0-0.git20160317.1.mga6
+ Revision: 995873
- new snapshot release: 2.0.0-git20160317 (second attempt of freerdp 2)
  * commit: 75ae3f58df5a14b4a67439aca96061a9c2ea5040
- now rdtk and winpr libmajor is 2
- update files list

* Fri Mar 04 2016 daviddavid <daviddavid> 2.0.0-0.git20160303.2.mga6
+ Revision: 985442
- add back our arm arch on armv5tl (removed accidentally)

* Fri Mar 04 2016 daviddavid <daviddavid> 2.0.0-0.git20160303.1.mga6
+ Revision: 985437
- new snapshot release: 2.0.0-git20160303 (first attempt of freerdp 2)
  * commit: 167fd478609cb5911bba0760d8e57f21806d8199
- remove merged upstream patches
- update files list

* Wed Jan 20 2016 daviddavid <daviddavid> 2.0.0-0.git20160112.2.mga6
+ Revision: 926048
- add our arm arch on armv5tl

* Thu Jan 14 2016 daviddavid <daviddavid> 2.0.0-0.git20160112.1.mga6
+ Revision: 922970
- new snapshot release: 2.0.0-git20160112
  * commit: 9b8b1d6480245cc3dbe14d3899a5deb323e5bfe5
- add patch1 to fix installation of winpr-wtypes.h and winpr-version.h headers files

* Mon Dec 14 2015 daviddavid <daviddavid> 2.0.0-0.git20151210.2.mga6
+ Revision: 910353
- conflict old library to ease update
- enable ffmpeg support
- add patch0 to fix installation of winpr-makecert and winpr-hash targets

* Fri Dec 11 2015 daviddavid <daviddavid> 2.0.0-0.git20151210.1.mga6
+ Revision: 909404
- new snapshot release: 2.0.0-git20151210
  * commit: 70b9e994e1f393021849865e0bc3f5985878c402
- enable gsm and jpeg support
- enable pcsclite and wayland-client support
- enable xdamage and systemd support
- enable freerdp-server support
- fix License

* Sat Nov 28 2015 neoclust <neoclust> 1.2.0-4.git20151016.2.mga6
+ Revision: 906773
- Add cmake switches for ARM from fedora

* Fri Oct 16 2015 daviddavid <daviddavid> 1.2.0-4.git20151016.1.mga6
+ Revision: 892221
- new snapshot release: 1.2.0-git20151016 (fix build failure for new gstreamer versions)
  * commit: 7aca1e0dc506bc91cca3f3b9e05c8bd653b09032

* Sun Sep 20 2015 daviddavid <daviddavid> 1.2.0-4.git20150918.2.mga6
+ Revision: 882007
- new snapshot release: 1.2.0-git20150918
  * commit: d1cb3410de0d1c7b2bb8a5e201690799b5f485fb

* Thu Sep 03 2015 daviddavid <daviddavid> 1.2.0-4.git72d9014.1.mga6
+ Revision: 872508
- new snapshot release: 1.2.0-git72d901454c45f87e625e474b2ee7f94e1b1b64d8
  * needed for Remmina 1.2.0 build
- update URL and Source URL
- remove no more needed previous cmake patch
- update file list
- introduce license macro

* Thu Aug 27 2015 ovitters <ovitters> 1.2.0-3.mga6
+ Revision: 870296
- enable xrandr,xi

* Thu Aug 27 2015 ovitters <ovitters> 1.2.0-2.mga6
+ Revision: 870292
- enable gstreamer 1.0 support

* Thu Aug 27 2015 ovitters <ovitters> 1.2.0-1.mga6
+ Revision: 870273
- really add patch
- add patch to fix build with new cmake
- new version 1.2.0-beta1-android9

* Wed Oct 15 2014 umeabot <umeabot> 1.0.2-5.mga5
+ Revision: 740922
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.2-4.mga5
+ Revision: 679349
- Mageia 5 Mass Rebuild

* Tue Jul 01 2014 luigiwalser <luigiwalser> 1.0.2-3.mga5
+ Revision: 641803
- rebuild to update release tag

* Tue Jul 01 2014 luigiwalser <luigiwalser> 1.0.2-2.mga5
+ Revision: 641790
- add patches from opensuse to fix CVE-2014-0250 and CVE-2014-0791

* Sat Oct 19 2013 umeabot <umeabot> 1.0.2-2.mga4
+ Revision: 527532
- Mageia 4 Mass Rebuild

* Sun Jun 09 2013 fwang <fwang> 1.0.2-1.mga4
+ Revision: 441066
- new version 1.0.2

* Fri Jan 11 2013 umeabot <umeabot> 1.0.1-2.mga3
+ Revision: 350933
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Aug 07 2012 guillomovitch <guillomovitch> 1.0.1-1.mga3
+ Revision: 279710
- new version

* Thu Mar 03 2011 saispo <saispo> 0.8.2-1.mga1
+ Revision: 63376
- imported package freerdp

